EnterpriseService

Struct EnterpriseService 

pub struct EnterpriseService { /* private fields */ }
Available on crate feature _async only.
Async enterprise service. Async enterprise robot service.

Implementations

Source

impl EnterpriseService

pub async fn get_access_token(&self) -> Result<String>

Retrieves enterprise access token and refreshes cache when needed.

pub async fn send_group_message( &self, open_conversation_id: &str, title: &str, text: &str, ) -> Result<String>

Sends a group message to a conversation.

pub async fn send_oto_message( &self, user_id: &str, title: &str, text: &str, ) -> Result<String>

Sends a one-to-one message to a user.

pub async fn contact_get_user( &self, request: ContactGetUserRequest, ) -> Result<ContactUser>

Gets user details by user id.

pub async fn contact_get_user_by_mobile( &self, request: ContactGetUserByMobileRequest, ) -> Result<ContactUser>

Gets user details by mobile.

pub async fn contact_get_user_by_unionid( &self, request: ContactGetUserByUnionIdRequest, ) -> Result<ContactUser>

Gets user details by union id.

pub async fn contact_list_users( &self, request: ContactListUsersRequest, ) -> Result<ContactListUsersResult>

Lists users in a department.

pub async fn contact_create_user( &self, request: ContactCreateUserRequest, ) -> Result<ContactCreateUserResult>

Creates a user.

pub async fn contact_update_user( &self, request: ContactUpdateUserRequest, ) -> Result<()>

Updates a user.

pub async fn contact_delete_user( &self, request: ContactDeleteUserRequest, ) -> Result<()>

Deletes a user.

pub async fn contact_get_department( &self, request: ContactGetDepartmentRequest, ) -> Result<ContactDepartment>

Gets department details.

pub async fn contact_list_sub_departments( &self, request: ContactListSubDepartmentsRequest, ) -> Result<ContactListSubDepartmentsResult>

Lists child departments.

pub async fn contact_list_sub_department_ids( &self, request: ContactListSubDepartmentIdsRequest, ) -> Result<ContactListSubDepartmentIdsResult>

Lists child department ids.

pub async fn contact_create_department( &self, request: ContactCreateDepartmentRequest, ) -> Result<ContactCreateDepartmentResult>

Creates a department.

pub async fn contact_update_department( &self, request: ContactUpdateDepartmentRequest, ) -> Result<()>

Updates a department.

pub async fn contact_delete_department( &self, request: ContactDeleteDepartmentRequest, ) -> Result<()>

Deletes a department.

pub async fn approval_create_process_instance( &self, request: ApprovalCreateProcessInstanceRequest, ) -> Result<String>

Creates an approval process instance and returns its id.

pub async fn approval_get_process_instance( &self, process_instance_id: &str, ) -> Result<ApprovalProcessInstance>

Gets approval process instance details.

pub async fn approval_list_process_instance_ids( &self, request: ApprovalListProcessInstanceIdsRequest, ) -> Result<ApprovalListProcessInstanceIdsResult>

Lists approval process instance ids.

pub async fn approval_terminate_process_instance( &self, request: ApprovalTerminateProcessInstanceRequest, ) -> Result<()>

Terminates an approval process instance.

pub async fn reply_message( &self, data: &Value, title: &str, text: &str, ) -> Result<String>

Replies to an incoming callback message.

For private chats, this sends OTO message to senderStaffId; for group chats, it sends a group message to conversationId.